﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Fuhrpark
{
    class Kennzeichen
    {
        string ort;
        string mitte;
        int zahl;
        public Kennzeichen(string ort, string mitte, int zahl)
        {
            if (ort.Length == 0 || ort.Length > 3 || mitte.Length == 0 || mitte.Length > 2 || zahl < 1 || zahl > 9999 )
            {
                throw new Exception(); // später besser
            }

            this.ort = ort;
            this.mitte = mitte;
            this.zahl = zahl;
        }

        public Kennzeichen(string kennzeichen)
        {
            string[] teile = kennzeichen.Split('-');
            if(teile.Length != 3)
            {
                throw new Exception(); // später besser
            }

            string ort = teile[0];
            string mitte = teile[1];
            int zahl = int.Parse(teile[2]);

            if (ort.Length == 0 || ort.Length > 3 || mitte.Length == 0 || mitte.Length > 2 || zahl < 1 || zahl > 9999)
            {
                throw new Exception(); // später besser
            }

            this.ort = ort;
            this.mitte = mitte;
            this.zahl = zahl;
        }

        public override string ToString()
        {
            return ort + "-" + mitte + "-" + zahl;
        }
    }

    class Kfz
    {
        Kennzeichen kennzeichen;
        int kmStand;
        DateTime erstzulassung;
        public enum Antrieb { Benzin, Diesel, Elektro, Sonstige }
        Antrieb antrieb;

        public Kfz(string kennzeichenString, int kmStand, DateTime erstzulassung, Antrieb antrieb)
        {
            this.kennzeichen = new Kennzeichen(kennzeichenString);
            this.kmStand = kmStand;
            this.erstzulassung = erstzulassung;
            this.antrieb = antrieb;
        }

        public virtual double BerechneMaut(int autobahnKm)
        {
            return 0.0;
        }

        public override string ToString()
        {
            return kennzeichen.ToString();
        }
    }

    class PKW : Kfz
    {
        int zahlSitzplätze;
        public PKW(string kennzeichen, int kmStand, DateTime erstzulassung, Antrieb antrieb, int zahlSitzplätze)
        : base(kennzeichen, kmStand, erstzulassung, antrieb)
        {
            this.zahlSitzplätze = zahlSitzplätze;
        }
    }

    class LKW : Kfz
    {
        int maximaleNutzlast;
        public LKW(string kennzeichen, int kmStand, DateTime erstzulassung, Antrieb antrieb, int maximaleNutzlast)
        : base(kennzeichen, kmStand, erstzulassung, antrieb)
        {
            this.maximaleNutzlast = maximaleNutzlast;
        }

        public override double BerechneMaut(int autobahnKm)
        {
            return 0.2 * autobahnKm;
        }

        public override string ToString()
        {
            return "LKW: " + base.ToString();
        }
    }
}
